pub type ProgressFn<'a> = dyn Fn(u64) + 'a;Expand description
A callback invoked with the number of bytes newly written to the destination as a download streams in. Used to drive a progress bar without this crate depending on a UI crate. Reported incrementally, chunk by chunk.